==> haskell-hls-splice-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-splice-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-splice-plugin-2.1.0.0-rRzuNHqwjC4AVHvGWpngL
key:                  hls-splice-plugin-2.1.0.0-rRzuNHqwjC4AVHvGWpngL
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e44b094197e647ae0606a77b8dc2ccd5
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.1.0.0-rRzuNHqwjC4AVHvGWpngL
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1 containers-0.6.7
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    extra-1.7.16-KxrHBQWVwMp2M62XitBte8
    foldl-1.4.18-5c5FYHd5uyHBYUMYoaJHy6 ghc-9.4.8
    ghc-exactprint-1.6.1-7axuNmUvC9rLDVsc4zeWrL
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    hls-refactor-plugin-2.1.0.0-1mgIyR2L99XJYvvY3SkUi6
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg mtl-2.2.2
    retrie-1.2.3-1y6GbD5JAzcAnLlEmWsfCh
    syb-0.7.3-Lap6GPARkRXCVbqA2faY6P text-2.0.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-splice-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-splice-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-splice-plugin-2.1.0.0-Wz22RZfDYb9ofim08bpxE
key:                  hls-splice-plugin-2.1.0.0-Wz22RZfDYb9ofim08bpxE
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  039d32df66d60ce04735d73b5a231541
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.1.0.0-Wz22RZfDYb9ofim08bpxE
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1 containers-0.6.7
    dlist-1.0-DlYyWPxbaG7vpSilKIFCh extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E
    foldl-1.4.18-OTrisf5BCQDMMVbl8USct ghc-9.4.8
    ghc-exactprint-1.6.1-I9AXRGbygyx7CNm2jZnyfK
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    hls-refactor-plugin-2.1.0.0-ExDUElgsYmt9j5A89B9r6p
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN mtl-2.2.2
    retrie-1.2.3-4xmNpLWUS55A2ToWNKattd
    syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt text-2.0.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
